---
name: "vcmibuilder"
section: "1"
platform: "linux"
package: "vcmi"
version: "1.6.5+dfsg-2"
release: "Debian 13 (Trixie)"
platforms: ["linux"]
url: "https://new.carta.tech/vcmibuilder"
---

# vcmibuilder(1)

Extract bitmaps, animations, text, music and video from Heroes of Might and Magic 3.

## NAME

vcmibuilder - Extract bitmaps, animations, text, music and video from Heroes of Might and Magic 3.

## SYNOPSIS

- **vcmibuilder** \[options\]

  ## DESCRIPTION

Vcmi is a re-implementation of the Heroes of Might and Magic 3 engine. To play the game you need to own the proprietary assets like graphics, music and campaigns and scenarios. This information can be extracted from either the Good Old Games installer, the Heroes of Might and Magic 3 installation CDs or from a directory where Heroes of Might and Magic 3 was installed.

VCMI data builder utility

## OPTIONS

- **--cd1** DIRECTORY

  Path to mounted first CD with Heroes 3 install files Requires unshield

- **--cd2** DIRECTORY

  Path to second CD with Heroes 3 data files.

- **--gog** EXECUTABLE

  Path to gog.com executable Requires innoextract ( http://constexpr.org/innoextract/ )

- **--data** DIRECTORY

  Path to installed Heroes 3 data

- **--convertMP3**

  Convert all mp3 files into ogg/vorbis Requires ffmpeg or avconv

- **--dest** DIRECTORY

  Path where resulting data will be placed. Default is ~/.local/share/vcmi

- **--validate**

  Run basic validness checks

## EXAMPLES

Using the Good Old Games installer:

    vcmibuilder --gog /path/to/gog.com/installer

Using the Heroes of Might and Magic 3 installation CDs:

    vcmibuilder --cd1 /path/to/iso/or/cd --cd2 /path/to/second/cd

Using a directory in which Heroes of Might and Magic 3 was installed:

    vcmibuilder --data /path/to/h3/data

## REPORTING BUGS

Report bugs to http://bugs.debian.org/vcmi or vcmi@packages.qa.debian.org
